#! /bin/sh
#+
#
# ===================
# superbib_profile.sh
# ===================
#
# ---------------------------
# define SUPERBIB environment
# ---------------------------
#
# SYNOPSIS
# ========
#
# Online usage ::
#
#  $ . ./superbib_profile.sh -d directory -i indir -o outdir -t tempdir
#
# In ${HOME}/.profile, add the following line ::
#
#  . superbib_profile.sh -d directory  -i indir -o outdir -t tempdir
#
# DESCRIPTION
# ===========
#
# define SUPERBIB environment
#
# ${SUPERBIB} is the base directory of tools.
#
# ${SUPERBIB_LOG} is the directory where log files  will be written.
#
# ${SUPERBIB_ID} is the directory where input files must be.
#
# ${SUPERBIB_OD}  is the directory where output files will be written.
#
# MANPATH++
#
# EXAMPLES
# ========
#
# For fplod, on aedon.locean-ipsl.upmc.fr::
#
#  $ cd /usr/home/fplod/src/superbib/superbib_ws/
#  $ . ./src/superbib_profile.sh \
#    -d $(pwd) \
#    -i /usr/temp/${LOGNAME}/superbib_d/ \
#    -o /usr/temp/${LOGNAME}/superbib_d/ \
#    -t /usr/temp/${LOGNAME}/log/
#
# TODO
# ====
#
# ++ option bavarde
#
# ++ machine dependant
#
# ++ compilateur dependant
#
# ++ pas de MANPATH defini par defaut sur zeus
#
# EVOLUTIONS
# ==========
#
# $Id$
#
# - fplod 2008-10-31T11:17:24Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * creation ++ pas encore en service
#
#-
system=$(uname)
case "${system}" in
   AIX|IRIX64)
      echo " www : no specific posix checking"
   ;;
   *)
      set -o posix
   ;;
esac
unset system
#
# as this script might be launch in .profile, command is forced.
command=superbib_profile.sh
#
usage=" Usage : ${command} -d directory -i indir -o outdir -t tempdir"
#
while [ ! -z "${1}" ] # ++ pb bash
do
   case ${1} in
      -d) # directory for application choosen by user (see svn checkout command used)
         directory=${2}
         shift
      ;;
      -i) # directory for inputs choosen by user
         indir=${2}
         shift
      ;;
      -o) # directory for outputs choosen by user
         outdir=${2}
         shift
      ;;
      -t) # directory for temporary outputs choosen by user
         tempdir=${2}
         shift
      ;;
      *) # other choice
        echo "eee : unknown option ${1}"
        echo "${usage}"
        # nb : no exit because this file should be launched by login process
      ;;
   esac
   shift # next flag
done
unset usage
#
# check for ${directory}
if [ ! -d ${directory} ]
then
   echo " eee : ${directory} not found"
   # nb : no exit because this file should be launched by login process
fi
#
# check for permission on directory
if [ ! -x ${directory} ]
then
   echo " eee : ${directory} not reachable"
   # nb : no exit because this file should be launched by login process
fi
#
SUPERBIB=${directory}
export SUPERBIB
#
# add SUPERBIB tools to PATH
# if not already done
echo ${PATH} | grep -q ${SUPERBIB}
test_path=${?}
if [ ${test_path} -ne 0 ]
then
   PATH=${SUPERBIB}/:${PATH}
   export PATH
else
   # option bavarde oui/non pas encore implante ++
   echo "${command} : iii : ${SUPERBIB}/ already in \${PATH}"
fi
unset test_path
#
# add SUPERBIB manuals to MANPATH
# if not already done
echo ${MANPATH} | grep -q ${SUPERBIB}
test_manpath=${?}
if [ ${test_manpath} -ne 0 ]
then
   MANPATH=${SUPERBIB}/doc/manuals/man/:${MANPATH}
   export MANPATH
else
   # option bavarde oui/non pas encore implante ++
   echo "${command} : iii : ${SUPERBIB}/doc/manuals/man/ already in \${MANPATH}"
fi
unset test_manpath
#
SUPERBIB_LOG=${tempdir}
export SUPERBIB_LOG
unset tempdir
if [ ! -d ${SUPERBIB_LOG} ]
then
   mkdir -p ${SUPERBIB_LOG}
   echo "${command} : iii : creation of \${SUPERBIB_LOG}"
fi
# check for permission on SUPERBIB_LOG
if [ ! -x ${SUPERBIB_LOG} ]
then
  echo " eee : ${SUPERBIB_LOG} not reachable"
  # nb : no exit because this file should be launched by login process
fi
#
# check for permission on SUPERBIB_LOG
if [ ! -w ${SUPERBIB_LOG} ]
then
   echo " eee : ${SUPERBIB_LOG} not writable"
   # nb : no exit because this file shouldreachable be launched by login process
fi
#
EDITOR=vi
export EDITOR
#
# io directories
SUPERBIB_ID=${indir}
export SUPERBIB_ID
unset indir
if [ ! -d ${SUPERBIB_ID} ]
then
   mkdir -p ${SUPERBIB_ID}
   echo "${command} : iii : creation of \${SUPERBIB_ID}"
fi
# check for permission on SUPERBIB_ID
if [ ! -x ${SUPERBIB_ID} ]
then
   echo " eee : ${SUPERBIB_ID} not reachable"
   # nb : no exit because this file should be launched by login process
fi
#
SUPERBIB_OD=${outdir}
export SUPERBIB_OD
unset outdir
if [ ! -d ${SUPERBIB_OD} ]
then
    mkdir -p ${SUPERBIB_OD}
    echo "${command} : iii : creation of \${SUPERBIB_OD}"
fi
# check for permission on SUPERBIB_OD
if [ ! -x ${SUPERBIB_OD} ]
then
   echo " eee : ${SUPERBIB_OD} not reachable"
   # nb : no exit because this file should be launched by login process
fi
if [ ! -w ${SUPERBIB_OD} ]
then
   echo " eee : ${SUPERBIB_OD} not writable"
   # nb : no exit because this file should be launched by login process
fi
#
# end
unset command
# nb : no exit because this file should be launched by login process
